@@ -8,7 +8,7 @@ use Carp qw( croak );
 use Exporter ();
 
 # ABSTRACT: Portably generate config for any shell
-our $VERSION = '0.24'; # VERSION
+our $VERSION = '0.25'; # VERSION
 
 
 sub new
@@ -371,12 +371,12 @@ sub generate_file
 our @EXPORT_OK = qw( win32_space_be_gone );
 
 
-*_win_to_posix_path = $^O eq 'cygwin' ? \&Cygwin::win_to_posix_path : sub { $_[0] };
-*_posix_to_win_path = $^O eq 'cygwin' ? \&Cygwin::posix_to_win_path : sub { $_[0] };
+*_win_to_posix_path = $^O =~ /^(cygwin|msys)$/ ? \&Cygwin::win_to_posix_path : sub { $_[0] };
+*_posix_to_win_path = $^O =~ /^(cygwin|msys)$/ ? \&Cygwin::posix_to_win_path : sub { $_[0] };
 
 sub win32_space_be_gone
 {
-  return @_ if $^O !~ /^(MSWin32|cygwin)$/;
+  return @_ if $^O !~ /^(MSWin32|cygwin|msys)$/;
   map { /\s/ ? _win_to_posix_path(Win32::GetShortPathName(_posix_to_win_path($_))) : $_ } @_;
 }
 
@@ -394,7 +394,7 @@ Shell::Config::Generate - Portably generate config for any shell
 
 =head1 VERSION
 
-version 0.24
+version 0.25
 
 =head1 SYNOPSIS
 
